auditok.dataset — auditok 0.1.4 documentation

# auditok.dataset

This module contains links to audio files you can use for test purposes.

`auditok.dataset.` `one_to_six_arabic_16000_mono_bc_noise` = '/usr/local/lib/python2.7/dist-packages/auditok-0.1.4-py2.7.egg/auditok/data/1to6arabic_16000_mono_bc_noise.wav'

  A wave file that contains a pronunciation of Arabic numbers from 1 to 6

`auditok.dataset.` `was_der_mensch_saet_mono_44100_lead_trail_silence` = '/usr/local/lib/python2.7/dist-packages/auditok-0.1.4-py2.7.egg/auditok/data/was_der_mensch_saet_das_wird_er_vielfach_ernten_44100Hz_mono_lead_trail_silence.wav'

  A wave file that contains a sentence between long leading and trailing periods of silence